@@ -1,7 +1,15 @@
 from functools import lru_cache
 
-__version__ = '0.0.1'
-default_app_config = 'slackbot.apps.SlackbotConfig'
+__version__ = '0.0.3'
+
+# set default_app_config when using django earlier than 3.2
+try:
+    import django
+
+    if django.VERSION < (3, 2):
+        default_app_config = 'slackbot.apps.SlackbotConfig'
+except ImportError:
+    pass
 
 
 @lru_cache
